@@ -556,10 +556,11 @@ class AlterQuery(DDLQuery):
             )):
                 print_warn(f'schema validation using {tok}')
 
-            elif tok.match(tokens.Name.Builtin, (
-                'integer', 'bool', 'char', 'date', 'boolean',
-                'datetime', 'float', 'time', 'number', 'string'
-            )):
+            elif tok.match(tokens.Name.Builtin, '.*', regex=True):
+                print_warn('column type validation')
+                self._type_code = str(tok)
+
+            elif tok.match(tokens.Keyword, 'double'):
                 print_warn('column type validation')
                 self._type_code = str(tok)
 
